@@ -2,10 +2,10 @@
 # Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
 # See the LICENSE file in the project root for more information
 
-package Search::Elasticsearch::Client::6_0::Direct;
-$Search::Elasticsearch::Client::6_0::Direct::VERSION = '7.711001';
+package Search::Elasticsearch::Client::7_0::Direct;
+$Search::Elasticsearch::Client::7_0::Direct::VERSION = '7.30';
 use Moo;
-with 'Search::Elasticsearch::Client::6_0::Role::API';
+with 'Search::Elasticsearch::Client::7_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 
 use Search::Elasticsearch::Util qw(parse_params is_compat);
@@ -13,16 +13,27 @@ use namespace::clean;
 
 sub _namespace {__PACKAGE__}
 
-has 'cluster'  => ( is => 'lazy', init_arg => undef );
-has 'nodes'    => ( is => 'lazy', init_arg => undef );
-has 'indices'  => ( is => 'lazy', init_arg => undef );
-has 'ingest'   => ( is => 'lazy', init_arg => undef );
-has 'snapshot' => ( is => 'lazy', init_arg => undef );
-has 'cat'      => ( is => 'lazy', init_arg => undef );
-has 'ccr'      => ( is => 'lazy', init_arg => undef );
-has 'ilm'      => ( is => 'lazy', init_arg => undef );
-has 'tasks'    => ( is => 'lazy', init_arg => undef );
-has 'xpack'    => ( is => 'lazy', init_arg => undef );
+has 'cluster'    => ( is => 'lazy', init_arg => undef );
+has 'nodes'      => ( is => 'lazy', init_arg => undef );
+has 'indices'    => ( is => 'lazy', init_arg => undef );
+has 'ingest'     => ( is => 'lazy', init_arg => undef );
+has 'snapshot'   => ( is => 'lazy', init_arg => undef );
+has 'cat'        => ( is => 'lazy', init_arg => undef );
+has 'ccr'        => ( is => 'lazy', init_arg => undef );
+has 'ilm'        => ( is => 'lazy', init_arg => undef );
+has 'tasks'      => ( is => 'lazy', init_arg => undef );
+has 'xpack'      => ( is => 'lazy', init_arg => undef );
+has 'data_frame' => ( is => 'lazy', init_arg => undef );
+has 'graph'      => ( is => 'lazy', init_arg => undef );
+has 'license'    => ( is => 'lazy', init_arg => undef );
+has 'migration'  => ( is => 'lazy', init_arg => undef );
+has 'ml'         => ( is => 'lazy', init_arg => undef );
+has 'monitoring' => ( is => 'lazy', init_arg => undef );
+has 'rollup'     => ( is => 'lazy', init_arg => undef );
+has 'security'   => ( is => 'lazy', init_arg => undef );
+has 'sql'        => ( is => 'lazy', init_arg => undef );
+has 'ssl'        => ( is => 'lazy', init_arg => undef );
+has 'watcher'    => ( is => 'lazy', init_arg => undef );
 has 'bulk_helper_class'   => ( is => 'rw' );
 has 'scroll_helper_class' => ( is => 'rw' );
 has '_bulk_class'         => ( is => 'lazy' );
@@ -63,16 +74,27 @@ sub scroll_helper {
 }
 
 #===================================
-sub _build_cluster  { shift->_build_namespace('Cluster') }
-sub _build_nodes    { shift->_build_namespace('Nodes') }
-sub _build_indices  { shift->_build_namespace('Indices') }
-sub _build_ingest   { shift->_build_namespace('Ingest') }
-sub _build_snapshot { shift->_build_namespace('Snapshot') }
-sub _build_cat      { shift->_build_namespace('Cat') }
-sub _build_ccr      { shift->_build_namespace('CCR') }
-sub _build_ilm      { shift->_build_namespace('ILM') }
-sub _build_tasks    { shift->_build_namespace('Tasks') }
-sub _build_xpack    { shift->_build_namespace('XPack') }
+sub _build_cluster    { shift->_build_namespace('Cluster') }
+sub _build_nodes      { shift->_build_namespace('Nodes') }
+sub _build_indices    { shift->_build_namespace('Indices') }
+sub _build_ingest     { shift->_build_namespace('Ingest') }
+sub _build_snapshot   { shift->_build_namespace('Snapshot') }
+sub _build_cat        { shift->_build_namespace('Cat') }
+sub _build_ccr        { shift->_build_namespace('CCR') }
+sub _build_ilm        { shift->_build_namespace('ILM') }
+sub _build_tasks      { shift->_build_namespace('Tasks') }
+sub _build_xpack      { shift->_build_namespace('XPack') }
+sub _build_data_frame { shift->_build_namespace('DataFrame') }
+sub _build_graph      { shift->_build_namespace('Graph') }
+sub _build_license    { shift->_build_namespace('License') }
+sub _build_migration  { shift->_build_namespace('Migration') }
+sub _build_ml         { shift->_build_namespace('ML') }
+sub _build_monitoring { shift->_build_namespace('Monitoring') }
+sub _build_rollup     { shift->_build_namespace('Rollup') }
+sub _build_security   { shift->_build_namespace('Security') }
+sub _build_sql        { shift->_build_namespace('SQL') }
+sub _build_ssl        { shift->_build_namespace('SSL') }
+sub _build_watcher    { shift->_build_namespace('Watcher') }
 #===================================
 
 __PACKAGE__->_install_api('');
@@ -85,11 +107,11 @@ __PACKAGE__->_install_api('');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::6_0::Direct - Thin client with full support for Elasticsearch 6.x APIs
+Search::Elasticsearch::Client::7_0::Direct - Thin client with full support for Elasticsearch 7.x APIs
 
 =head1 VERSION
 
-version 7.711001
+version 7.30
 
 =head1 SYNOPSIS
 
@@ -97,7 +119,7 @@ Create a client:
 
     use Search::Elasticsearch;
     my $e = Search::Elasticsearch->new(
-        client => '6_0::Direct'
+        client => '7_0::Direct'
     );
 
 Index a doc:
@@ -186,11 +208,11 @@ Index lifecycle management requests:
 
 =head1 DESCRIPTION
 
-The L<Search::Elasticsearch::Client::6_0::Direct> class provides the
-Elasticsearch 6.x compatible client returned by:
+The L<Search::Elasticsearch::Client::7_0::Direct> class provides the
+Elasticsearch 7.x compatible client returned by:
 
     $e = Search::Elasticsearch->new(
-        client => "6_0::Direct"  # default
+        client => "7_0::Direct"  # default
     );
 
 It is intended to be as close as possible to the native REST API that
@@ -205,16 +227,20 @@ and the L<cluster|/cluster()>.
 
 =head1 PREVIOUS VERSIONS OF ELASTICSEARCH
 
-This version of the client supports the Elasticsearch 6.0 branch,
+This version of the client supports the Elasticsearch 7.0 branch,
 which is not backwards compatible with earlier branches.
 
-If you need to talk to a version of Elasticsearch before 6.0.0, please
+If you need to talk to a version of Elasticsearch before 7.0.0, please
 install one of the following modules:
 
 =over
 
 =item *
 
+L<Search::Elasticsearch::Client::6_0>
+
+=item *
+
 L<Search::Elasticsearch::Client::5_0>
 
 =item *
@@ -285,7 +311,7 @@ UTF-8 bytes and passed as is:
 
 =head2 Boolean parameters
 
-Elasticsearch 6.0.0 and above no longer accepts truthy and falsey values for booleans.  Instead,
+Elasticsearch 7.0.0 and above no longer accepts truthy and falsey values for booleans.  Instead,
 it will accept only a JSON C<true> or C<false>, or the string equivalents C<"true"> or C<"false">.
 
 In the Perl client, you can use the following values:
@@ -339,12 +365,12 @@ Multiple error codes can be specified with an array:
 =head2 C<bulk_helper_class>
 
 The class to use for the L</bulk_helper()> method. Defaults to
-L<Search::Elasticsearch::Client::6_0::Bulk>.
+L<Search::Elasticsearch::Client::7_0::Bulk>.
 
 =head2 C<scroll_helper_class>
 
 The class to use for the L</scroll_helper()> method. Defaults to
-L<Search::Elasticsearch::Client::6_0::Scroll>.
+L<Search::Elasticsearch::Client::7_0::Scroll>.
 
 =head1 GENERAL METHODS
 
@@ -366,7 +392,7 @@ response, otherwise it throws an error.
 
     $indices_client = $e->indices;
 
-Returns a L<Search::Elasticsearch::Client::6_0::Direct::Indices> object which can be used
+Returns a L<Search::Elasticsearch::Client::7_0::Direct::Indices> object which can be used
 for managing indices, eg creating, deleting indices, managing mapping,
 index settings etc.
 
@@ -374,28 +400,28 @@ index settings etc.
 
     $ingest_client = $e->ingest;
 
-Returns a L<Search::Elasticsearch::Client::6_0::Direct::Ingest> object which can be used
+Returns a L<Search::Elasticsearch::Client::7_0::Direct::Ingest> object which can be used
 for managing ingest pipelines.
 
 =head2 C<cluster()>
 
     $cluster_client = $e->cluster;
 
-Returns a L<Search::Elasticsearch::Client::6_0::Direct::Cluster> object which can be used
+Returns a L<Search::Elasticsearch::Client::7_0::Direct::Cluster> object which can be used
 for managing the cluster, eg cluster-wide settings and cluster health.
 
 =head2 C<nodes()>
 
     $node_client = $e->nodes;
 
-Returns a L<Search::Elasticsearch::Client::6_0::Direct::Nodes> object which can be used
+Returns a L<Search::Elasticsearch::Client::7_0::Direct::Nodes> object which can be used
 to retrieve node info and stats.
 
 =head2 C<snapshot()>
 
     $snapshot_client = $e->snapshot;
 
-Returns a L<Search::Elasticsearch::Client::6_0::Direct::Snapshot> object which
+Returns a L<Search::Elasticsearch::Client::7_0::Direct::Snapshot> object which
 is used for managing backup repositories and creating and restoring
 snapshots.
 
@@ -403,14 +429,14 @@ snapshots.
 
     $tasks_client = $e->tasks;
 
-Returns a L<Search::Elasticsearch::Client::6_0::Direct::Tasks> object which
+Returns a L<Search::Elasticsearch::Client::7_0::Direct::Tasks> object which
 is used for accessing the task management API.
 
 =head2 C<cat()>
 
     $cat_client = $e->cat;
 
-Returns a L<Search::Elasticsearch::Client::6_0::Direct::Cat> object which can be used
+Returns a L<Search::Elasticsearch::Client::7_0::Direct::Cat> object which can be used
 to retrieve simple to read text info for debugging and monitoring an
 Elasticsearch cluster.
 
@@ -418,14 +444,14 @@ Elasticsearch cluster.
 
     $ccr_client = $e->ccr;
 
-Returns a L<Search::Elasticsearch::Client::6_0::Direct::CCR> object which can be used
+Returns a L<Search::Elasticsearch::Client::7_0::Direct::CCR> object which can be used
 to handle cross-cluster replication requests.
 
 =head2 C<ilm()>
 
     $ilm_client = $e->ilm;
 
-Returns a L<Search::Elasticsearch::Client::6_0::Direct::ILM> object which can be used
+Returns a L<Search::Elasticsearch::Client::7_0::Direct::ILM> object which can be used
 to handle index lifecycle management requests.
 
 =head1 DOCUMENT CRUD METHODS
@@ -747,7 +773,7 @@ that need to be made, bulk requests greatly improve performance.
         body    => [ actions ]          # required
     );
 
-See L<Search::Elasticsearch::Client::6_0::Bulk> and L</bulk_helper()> for a helper module that makes
+See L<Search::Elasticsearch::Client::7_0::Bulk> and L</bulk_helper()> for a helper module that makes
 bulk indexing simpler to use.
 
 The C<bulk()> method can perform multiple L</index()>, L</create()>,
@@ -829,7 +855,7 @@ for more information.
     $bulk_helper = $e->bulk_helper( @args );
 
 Returns a new instance of the class specified in the L</bulk_helper_class>,
-which defaults to L<Search::Elasticsearch::Client::6_0::Bulk>.
+which defaults to L<Search::Elasticsearch::Client::7_0::Bulk>.
 
 =head2 C<mget()>
 
@@ -1150,7 +1176,7 @@ C<scroll> parameter, the C<scroll()>
 method allows you to keep pulling more results until the results
 are exhausted.
 
-See L</scroll_helper()> and L<Search::Elasticsearch::Client::6_0::Scroll> for a helper utility
+See L</scroll_helper()> and L<Search::Elasticsearch::Client::7_0::Scroll> for a helper utility
 which makes managing scroll requests much easier.
 
 Query string parameters:
@@ -1180,7 +1206,7 @@ up resources on the server.
     $scroll_helper = $e->scroll_helper( @args );
 
 Returns a new instance of the class specified in the L</scroll_helper_class>,
-which defaults to L<Search::Elasticsearch::Client::6_0::Scroll>.
+which defaults to L<Search::Elasticsearch::Client::7_0::Scroll>.
 
 =head2 C<msearch()>
 
@@ -1637,7 +1663,7 @@ Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
@@ -1647,5 +1673,5 @@ This is free software, licensed under:
 
 __END__
 
-# ABSTRACT: Thin client with full support for Elasticsearch 6.x APIs
+# ABSTRACT: Thin client with full support for Elasticsearch 7.x APIs
 
