@@ -15,8 +15,8 @@
 # specific language governing permissions and limitations
 # under the License.
 
-package Search::Elasticsearch::Client::6_0::Scroll;
-$Search::Elasticsearch::Client::6_0::Scroll::VERSION = '7.711001';
+package Search::Elasticsearch::Client::7_0::Scroll;
+$Search::Elasticsearch::Client::7_0::Scroll::VERSION = '7.30';
 use Moo;
 use Search::Elasticsearch::Util qw(parse_params throw);
 use namespace::clean;
@@ -24,7 +24,7 @@ use namespace::clean;
 has '_buffer' => ( is => 'ro' );
 
 with 'Search::Elasticsearch::Role::Is_Sync',
-    'Search::Elasticsearch::Client::6_0::Role::Scroll';
+    'Search::Elasticsearch::Client::7_0::Role::Scroll';
 
 #===================================
 sub BUILDARGS {
@@ -33,11 +33,6 @@ sub BUILDARGS {
     my $es = delete $params->{es};
     my $scroll = $params->{scroll} ||= '1m';
 
-    throw( 'Param',
-        'The (scroll_in_body) parameter has been replaced by (scroll_in_qs)' )
-        if exists $params->{scroll_in_body};
-
-    my $scroll_in_qs = delete $params->{scroll_in_qs};
     my $results      = $es->search($params);
 
     my $total = $results->{hits}{total};
@@ -48,7 +43,6 @@ sub BUILDARGS {
     return {
         es           => $es,
         scroll       => $scroll,
-        scroll_in_qs => $scroll_in_qs,
         aggregations => $results->{aggregations},
         facets       => $results->{facets},
         suggest      => $results->{suggest},
@@ -126,10 +120,7 @@ sub finish {
     my $scroll_id = $self->_scroll_id or return;
     $self->_clear_scroll_id;
 
-    my %args
-        = $self->scroll_in_qs
-        ? ( scroll_id => $scroll_id )
-        : ( body => { scroll_id => $scroll_id } );
+    my %args = ( body => { scroll_id => $scroll_id } );
     eval { $self->es->clear_scroll(%args) };
     return 1;
 }
@@ -142,11 +133,11 @@ sub finish {
 
 =head1 NAME
 
-Search::Elasticsearch::Client::6_0::Scroll - A helper module for scrolled searches
+Search::Elasticsearch::Client::7_0::Scroll - A helper module for scrolled searches
 
 =head1 VERSION
 
-version 7.711001
+version 7.30
 
 =head1 SYNOPSIS
 
@@ -176,17 +167,17 @@ until there are no more matching results, much like a cursor in an SQL
 database.
 
 Unlike paginating through results (with the C<from> parameter in
-L<search()|Search::Elasticsearch::Client::6_0::Direct/search()>),
+L<search()|Search::Elasticsearch::Client::7_0::Direct/search()>),
 scrolled searches take a snapshot of the current state of the index. Even
 if you keep adding new documents to the index or updating existing documents,
 a scrolled search will only see the index as it was when the search began.
 
 This module is a helper utility that wraps the functionality of the
-L<search()|Search::Elasticsearch::Client::6_0::Direct/search()> and
-L<scroll()|Search::Elasticsearch::Client::6_0::Direct/scroll()> methods to make
+L<search()|Search::Elasticsearch::Client::7_0::Direct/search()> and
+L<scroll()|Search::Elasticsearch::Client::7_0::Direct/scroll()> methods to make
 them easier to use.
 
-This class does L<Search::Elasticsearch::Client::6_0::Role::Scroll> and
+This class does L<Search::Elasticsearch::Client::7_0::Role::Scroll> and
 L<Search::Elasticsearch::Role::Is_Sync>.
 
 =head1 USE CASES
@@ -251,7 +242,7 @@ C<client_id>:
 
 Very often the I<something> that you will want to do with these results
 involves bulk-indexing them into a new index. The easiest way to
-do this is to use the built-in L<Search::Elasticsearch::Client::6_0::Direct/reindex()>
+do this is to use the built-in L<Search::Elasticsearch::Client::7_0::Direct/reindex()>
 functionality provided by Elasticsearch.
 
 =head1 METHODS
@@ -263,17 +254,15 @@ functionality provided by Elasticsearch.
     my $es = Search::Elasticsearch->new(...);
     my $scroll = $es->scroll_helper(
         scroll         => '1m',            # optional
-        scroll_in_qs   => 0|1,             # optional
         %search_params
     );
 
-The L<Search::Elasticsearch::Client::6_0::Direct/scroll_helper()> method loads
-L<Search::Elasticsearch::Client::6_0::Scroll> class and calls L</new()>,
+The L<Search::Elasticsearch::Client::7_0::Direct/scroll_helper()> method loads
+L<Search::Elasticsearch::Client::7_0::Scroll> class and calls L</new()>,
 passing in any arguments.
 
-You can specify a C<scroll> duration (which defaults to C<"1m">) and
-C<scroll_in_qs> (which defaults to C<false>). Any other parameters are
-passed directly to L<Search::Elasticsearch::Client::6_0::Direct/search()>.
+You can specify a C<scroll> duration (which defaults to C<"1m">).
+Any other parameters are passed directly to L<Search::Elasticsearch::Client::7_0::Direct/search()>.
 
 The C<scroll> duration tells Elasticearch how long it should keep the scroll
 alive.  B<Note>: this duration doesn't need to be long enough to process
@@ -282,10 +271,7 @@ The expiry gets renewed for another C<scroll> period every time new
 a new batch of results is retrieved from the cluster.
 
 By default, the C<scroll_id> is passed as the C<body> to the
-L<scroll|Search::Elasticsearch::Client::6_0::Direct/scroll()> request.
-To send it in the query string instead, set C<scroll_in_qs> to a true value,
-but be aware: when querying very many indices, the scroll ID can become
-too long for intervening proxies.
+L<scroll|Search::Elasticsearch::Client::7_0::Direct/scroll()> request.
 
 The C<scroll> request uses C<GET> by default.  To use C<POST> instead,
 set L<send_get_body_as|Search::Elasticsearch::Transport/send_get_body_as> to
@@ -379,11 +365,11 @@ How long the original search plus all subsequent batches took, in milliseconds.
 
 =over
 
-=item * L<Search::Elasticsearch::Client::6_0::Direct/search()>
+=item * L<Search::Elasticsearch::Client::7_0::Direct/search()>
 
-=item * L<Search::Elasticsearch::Client::6_0::Direct/scroll()>
+=item * L<Search::Elasticsearch::Client::7_0::Direct/scroll()>
 
-=item * L<Search::Elasticsearch::Client::6_0::Direct/reindex()>
+=item * L<Search::Elasticsearch::Client::7_0::Direct/reindex()>
 
 =back
 
@@ -393,7 +379,7 @@ Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2021 by Elasticsearch BV.
+This software is Copyright (c) 2020 by Elasticsearch BV.
 
 This is free software, licensed under:
 
